package App::typemap;
$App::typemap::VERSION = '0.001';
use strict;
use warnings;

1;

# ABSTRACT: A tool for manipulating typemaps

__END__

=pod

=encoding UTF-8

=head1 NAME

App::typemap - A tool for manipulating typemaps

=head1 VERSION

version 0.001

=head1 AUTHOR

Leon Timmermans <leont@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
